@@ -1,16 +1,22 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Css_Parser
  */
 
+if (file_exists(__DIR__ . '/Parser/vendor/autoload.php')) {
+    require_once __DIR__ . '/Parser/vendor/autoload.php';
+} else {
+    require_once __DIR__ . '/../../../bundle/vendor/autoload.php';
+}
+
 /**
  * Horde interface to the Sabberworm CSS Parser library.
  *
@@ -18,7 +24,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Css_Parser
  */
